snapshot: more renaming
authorBrian Norris <banorris@uci.edu>
Thu, 3 Jan 2013 20:24:34 +0000 (12:24 -0800)
committerBrian Norris <banorris@uci.edu>
Thu, 3 Jan 2013 20:24:34 +0000 (12:24 -0800)
main.cc
snapshot-interface.h
snapshot.cc

diff --git a/main.cc b/main.cc
index 6b9cb9054e7819496c9a9c6f8d652a45d6754abd..dc3f6f4dca002d6e763e5bbf25068260d3edc828 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -146,5 +146,5 @@ int main(int argc, char **argv)
        redirect_output();
 
        /* Let's jump in quickly and start running stuff */
        redirect_output();
 
        /* Let's jump in quickly and start running stuff */
-       initSnapshotLibrary(10000, 1024, 1024, 4000, &model_main);
+       snapshot_system_init(10000, 1024, 1024, 4000, &model_main);
 }
 }
index b024e5a83a06300eb0e7a95aeee4f9f326765995..7f4de211badfe57b580d224306b08c3ffce5929b 100644 (file)
@@ -1,5 +1,6 @@
-/** @file snapshot-interface.h
- *  @brief C++ layer on top of snapshotting system.
+/**
+ * @file snapshot-interface.h
+ * @brief C interface layer on top of snapshotting system
  */
 
 #ifndef __SNAPINTERFACE_H
  */
 
 #ifndef __SNAPINTERFACE_H
@@ -8,7 +9,7 @@
 typedef unsigned int snapshot_id;
 
 typedef void (*VoidFuncPtr)();
 typedef unsigned int snapshot_id;
 
 typedef void (*VoidFuncPtr)();
-void initSnapshotLibrary(unsigned int numbackingpages,
+void snapshot_system_init(unsigned int numbackingpages,
                unsigned int numsnapshots, unsigned int nummemoryregions,
                unsigned int numheappages, VoidFuncPtr entryPoint);
 
                unsigned int numsnapshots, unsigned int nummemoryregions,
                unsigned int numheappages, VoidFuncPtr entryPoint);
 
index 16b0b616e3ebca00a453d8d0903ddcb2e2838711..fb1f911557e09345ed7b8299e19d6edce97eb399 100644 (file)
@@ -398,10 +398,11 @@ static void fork_roll_back(snapshot_id theID)
 
 #endif /* !USE_MPROTECT_SNAPSHOT */
 
 
 #endif /* !USE_MPROTECT_SNAPSHOT */
 
/** The initSnapshotLibrary function initializes the snapshot library.
*  @param entryPoint the function that should run the program.
  */
  */
-void initSnapshotLibrary(unsigned int numbackingpages,
+void snapshot_system_init(unsigned int numbackingpages,
                unsigned int numsnapshots, unsigned int nummemoryregions,
                unsigned int numheappages, VoidFuncPtr entryPoint)
 {
@@ -398,10 +398,11 @@ static void fork_roll_back(snapshot_id theID)
 #endif /* !USE_MPROTECT_SNAPSHOT */
 
-/** The initSnapshotLibrary function initializes the snapshot library.
- *  @param entryPoint the function that should run the program.
+/**
+ * @brief Initializes the snapshot system
+ * @param entryPoint the function that should run the program.
  */
  */
                unsigned int numsnapshots, unsigned int nummemoryregions,
                unsigned int numheappages, VoidFuncPtr entryPoint)
 {